@@ -9,7 +9,7 @@ import os
 ROOT_DIR = (
     environ.Path(__file__) - 3
 )
-APPS_DIR = ROOT_DIR.path("backend")
+BACKEND_DIR = ROOT_DIR.path("backend")
 
 # env = environ.Env()  # django-sso-app
 
@@ -208,7 +208,7 @@ MIDDLEWARE = [
     "django.contrib.auth.middleware.AuthenticationMiddleware",
     "django_sso_app.core.middleware.authentication.DjangoSsoAppAuthenticationMiddleware",  # django-sso-app
     "django.contrib.messages.middleware.MessageMiddleware",
-    # "django.middleware.common.BrokenLinkEmailsMiddleware",
+    "django.middleware.common.BrokenLinkEmailsMiddleware",
     "django.middleware.clickjacking.XFrameOptionsMiddleware",
     "django.contrib.flatpages.middleware.FlatpageFallbackMiddleware",  # pai
 ]
@@ -233,7 +233,7 @@ STATIC_ROOT = str(PUBLIC_ROOT("static"))  # pai
 # https://docs.djangoproject.com/en/dev/ref/settings/#static-url
 STATIC_URL = "/static/"
 # https://docs.djangoproject.com/en/dev/ref/contrib/staticfiles/#std:setting-STATICFILES_DIRS
-STATICFILES_DIRS = [str(APPS_DIR.path("static"))]  # pai
+STATICFILES_DIRS = [str(BACKEND_DIR.path("static"))]  # pai
 # https://docs.djangoproject.com/en/dev/ref/contrib/staticfiles/#staticfiles-finders
 STATICFILES_FINDERS = [
     "django.contrib.staticfiles.finders.FileSystemFinder",
@@ -255,7 +255,7 @@ TEMPLATES = [
         # https://docs.djangoproject.com/en/dev/ref/settings/#std:setting-TEMPLATES-BACKEND
         "BACKEND": "django.template.backends.django.DjangoTemplates",
         # https://docs.djangoproject.com/en/dev/ref/settings/#template-dirs
-        "DIRS": [str(APPS_DIR.path("templates"))],
+        "DIRS": [str(BACKEND_DIR.path("templates"))],
         "OPTIONS": {
             # https://docs.djangoproject.com/en/dev/ref/settings/#template-loaders
             # https://docs.djangoproject.com/en/dev/ref/templates/api/#loader-types
@@ -296,7 +296,7 @@ CRISPY_TEMPLATE_PACK = "bootstrap4"
 # FIXTURES
 # ------------------------------------------------------------------------------
 # https://docs.djangoproject.com/en/dev/ref/settings/#fixture-dirs
-FIXTURE_DIRS = (str(APPS_DIR.path("fixtures")),)
+FIXTURE_DIRS = (str(ROOT_DIR.path("fixtures")),)
 
 # SECURITY
 # ------------------------------------------------------------------------------
