@@ -60,7 +60,7 @@ else:
 
 # Your stuff: custom urls includes go here
 urlpatterns += [
-    # path('users/', include('django_sso_app.backend.users.urls', namespace='users')),
+    path('users/', include('django_sso_app.backend.users.urls', namespace='users')),
 ]
 
 urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
