@@ -21,7 +21,7 @@ from allauth.account import app_settings as allauth_app_settings
 
 from .mixins import TryAuthenticateMixin
 from .utils import set_session_key, check_user_can_login
-from .exceptions import UnsubscribedUserException, DectivatedUserException, AdminUserCanNotLoginException
+from .exceptions import UnsubscribedUserException  #, DectivatedUserException, AdminUserCanNotLoginException
 from .apps.emails.models import EmailAddress
 from .apps.devices.models import Device
 from .apps.devices.utils import get_request_device
@@ -90,7 +90,7 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         # authentication backend
         logger.debug('adapter login')
 
-        check_user_can_login(user)
+        # check_user_can_login(user)
 
         if not hasattr(user, 'backend'):
             from .backends import DjangoSsoAppLoginAuthenticationBackend
@@ -115,7 +115,7 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
             logger.debug('django loggin in')
 
             # disabling rev update
-            setattr(user, '__django_sso_app__user_loggin_in', True)
+            setattr(user, '__dssoa__user_loggin_in', True)
 
             # django
             django_login(request, user)
@@ -187,7 +187,7 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         except UnsubscribedUserException:
             user_unsubscribed_at = user.sso_app_profile.unsubscribed_at
             if user_unsubscribed_at is not None:
-                set_session_key(request, '__django_sso_app__user_is_unsubscribed', str(user_unsubscribed_at))
+                set_session_key(request, '__dssoa__user_is_unsubscribed', str(user_unsubscribed_at))
 
         except Exception as e:
             logger.exception('adapter authentication failed "{}"'.format(str(e)))
@@ -305,7 +305,7 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         if _subscription_created:
             logger.info('Created service subscrption for "{}"'.format(profile))
 
-            setattr(profile.user, '__django_sso_app__subscription_updated', True)
+            setattr(profile.user, '__dssoa__subscription_updated', True)
 
             if update_rev:
                 profile.update_rev(commit)
