@@ -7,11 +7,10 @@ from rest_framework import serializers, exceptions
 from rest_framework.exceptions import ValidationError
 
 from allauth.account import app_settings as allauth_settings
-from allauth.account.models import EmailAddress
 from allauth.utils import get_username_max_length
 
+from ..apps.emails.models import EmailAddress
 from ..forms import LoginForm, SignupForm
-
 from .. import app_settings
 
 logger = logging.getLogger('django_sso_app.core.api')
