@@ -91,7 +91,7 @@ def passepartout_login_view(request, token):
             except Service.DoesNotExist:
                 raise Http404("Service not found")
 
-        set_session_key(request, '__django_sso_app__device__fingerprint', passepartout.device.fingerprint)
+        set_session_key(request, '__dssoa__device__fingerprint', passepartout.device.fingerprint)
 
         if is_last_bump:
             logger.info('Is last login bump')
@@ -131,7 +131,7 @@ def passepartout_login_view(request, token):
 
         else:
             if is_authenticated(user):
-                token = get_session_key(request, '__django_sso_app__jwt_token', None)
+                token = get_session_key(request, '__dssoa__jwt_token', None)
                 if token is None:
                     logger.error('no token in session')
                     raise Exception('no token in session')
