@@ -1,10 +1,11 @@
 import logging
 
 from allauth.account.adapter import get_adapter
-from django.contrib.auth import logout, get_user_model
+from django.contrib.auth import get_user_model
 from django.shortcuts import reverse, redirect
 from django.urls import reverse_lazy
-from django.views.generic.edit import UpdateView
+from django.views.generic import UpdateView
+from django.contrib.auth.mixins import LoginRequiredMixin
 
 from rest_framework import permissions
 from rest_framework import status
@@ -19,14 +20,14 @@ from ... import app_settings
 
 from ...permissions import is_staff, is_authenticated
 from ...utils import invalidate_cookie
-from ...mixins import TryAuthenticateMixin, WebpackBuiltTemplateViewMixin
+from ...mixins import WebpackBuiltTemplateViewMixin
 
 User = get_user_model()
 
 logger = logging.getLogger('django_sso_app.core.apps.profiles')
 
 
-class ProfileView(WebpackBuiltTemplateViewMixin):
+class ProfileView(LoginRequiredMixin, WebpackBuiltTemplateViewMixin):
     template_name = "account/profile.html"
 
     def get_object(self, queryset=None):
@@ -51,16 +52,20 @@ class ProfileView(WebpackBuiltTemplateViewMixin):
 
         return context
 
-    def get(self, *args, **kwargs):
+    def get(self, request, *args, **kwargs):
         logger.info('Getting profile')
+
+        if request.user.is_superuser:
+            return(redirect(reverse('admin:index')))
+
         try:
-            return super(ProfileView, self).get(*args, **kwargs)
+            return super(ProfileView, self).get(request, *args, **kwargs)
         except:
             logger.exception('Error getting profile')
             raise
 
 
-class ProfileUpdateView(UpdateView, WebpackBuiltTemplateViewMixin):
+class ProfileUpdateView(LoginRequiredMixin, UpdateView, WebpackBuiltTemplateViewMixin):
     model = Profile
     template_name = "account/profile_update.html"
     form_class = UserProfileForm
@@ -82,8 +87,8 @@ class ProfileUpdateView(UpdateView, WebpackBuiltTemplateViewMixin):
     def get(self, request, *args, **kwargs):
         logger.info('Getting profile update')
 
-        if request.user.is_anonymous:
-            return(redirect(reverse('account_login')))
+        if request.user.is_superuser:
+            return (redirect(reverse('admin:index')))
 
         try:
             profile = self.get_object()
@@ -96,8 +101,8 @@ class ProfileUpdateView(UpdateView, WebpackBuiltTemplateViewMixin):
     def post(self, request, *args, **kwargs):
         logger.info('Posting profile update')
 
-        if request.user.is_anonymous:
-            return(redirect(reverse('account_login')))
+        if request.user.is_superuser:
+            return (redirect(reverse('admin:index')))
 
         try:
             profile = self.get_object()
