@@ -29,16 +29,34 @@ class DjangoSsoAppUserModelMixin(object):
         return serialized
     """
 
+    @property
+    def password_has_been_updated(self):
+        return getattr(self, '__dssoa__old_password', None) != self.password
+
     @property
     def email_has_been_updated(self):
-        return getattr(self, '__django_sso_app__old_email', None) != self.email
+        return getattr(self, '__dssoa__old_email', None) != self.email
+
+    @property
+    def sso_app_new_email(self):
+        if self.email_has_been_updated:
+            return self.email
+
+    @property
+    def username_has_been_updated(self):
+        return getattr(self, '__dssoa__old_username', None) != self.username
+
+    @property
+    def sso_app_new_username(self):
+        if self.username_has_been_updated:
+            return self.username
 
     @property
     def password_has_been_hardened(self):
-        has_password = getattr(self, '__django_sso_app__old_password', self.password) not in [None, '']
+        has_password = getattr(self, '__dssoa__old_password', self.password) not in [None, '']
 
         if has_password:
-            old_hashed_password = getattr(self, '__django_sso_app__old_password')
+            old_hashed_password = getattr(self, '__dssoa__old_password')
             old_hasher = identify_hasher(old_hashed_password)
             new_hashed_password = self.password
             new_hasher = identify_hasher(new_hashed_password)
@@ -55,14 +73,15 @@ class DjangoSsoAppUserModelMixin(object):
 
     def __init__(self, *args, **kwargs):
         super(DjangoSsoAppUserModelMixin, self).__init__(*args, **kwargs)
-        setattr(self, '__django_sso_app__old_password', self.password)
-        setattr(self, '__django_sso_app__old_email', self.email)
+        setattr(self, '__dssoa__old_password', self.password)
+        setattr(self, '__dssoa__old_email', self.email)
+        setattr(self, '__dssoa__old_username', self.username)
         # setattr(self, '__serialized_as_string', self.serialized_as_string)  # replaced by '..__user_loggin_in'
 
-    def get_absolute_url(self):
+    def get_absolute_rest_url(self):
         profile = self.get_sso_app_profile()
         if profile is not None:
-            return reverse("django_sso_app_user:detail", kwargs={"sso_id": profile.sso_id})
+            return reverse("django_sso_app_user:rest-detail", kwargs={"sso_id": profile.sso_id})
 
     def get_sso_app_profile(self):
         return getattr(self, 'sso_app_profile', None)
@@ -83,10 +102,6 @@ class DjangoSsoAppUserModelMixin(object):
 
         return 0
 
-    @property
-    def sso_app_profile__sso_id(self):
-        return self.sso_id
-
     @property
     def is_unsubscribed(self):
         profile = self.get_sso_app_profile()
