@@ -201,8 +201,7 @@ class UserSerializer(AbsoluteUrlSerializer):
 
             user.email = new_email  # set user model email
 
-            setattr(user, '__django_sso_app__email_updated', True)
-            set_session_key(request, '__django_sso_app__user_email_updated', True)
+            set_session_key(request, '__dssoa__user_email_updated', True)
 
         if new_password is not None:
             logger.info('user "{}" is changing password for user "{}"'.format(requesting_user,
@@ -215,9 +214,7 @@ class UserSerializer(AbsoluteUrlSerializer):
                 logger.info('password is plain')
                 user.set_password(new_password)
 
-            setattr(user, '__django_sso_app__password_updated', True)
-
-        # updating user model
+        # finally updating user model
         user.save()
 
         return user
