@@ -7,12 +7,12 @@ from .views import (CheckUserExistenceApiView,
                     UserDetailApiView)
 
 _urlpatterns = [
-    url(r'^$', UserApiViewSet.as_view({'get': 'list', 'post': 'create'}), name='list'),
+    url(r'^$', UserApiViewSet.as_view({'get': 'list', 'post': 'create'}), name='rest-list'),
 
     url(r'^(?P<sso_id>[-_\w]+)/$',
         UserApiViewSet.as_view({'get': 'retrieve', 'patch': 'partial_update', 'delete': 'delete_test_user'},
-                               name='detail'),
-        name='detail'),
+                               name='rest-detail'),
+        name='rest-detail'),
 ]
 
 extra_urlpatterns = (format_suffix_patterns([
