@@ -60,8 +60,10 @@ def set_session_key(request, key, value):
     :param value:
     :return:
     """
-    # set session key
-    request.session[key] = value
+
+    #request.session[key] = value
+
+    setattr(request, key, value)
 
 
 def get_session_key(request, key, default=None):
@@ -72,21 +74,10 @@ def get_session_key(request, key, default=None):
     :param default:
     :return:
     """
-    # get session key
-    return request.session.get(key, default)
 
-""" noqa
-# Must use functions above because of django restframework
-# swapping the original request object instance with a new one..
+    #return request.session.get(key, default)
 
-def set_session_key(request, key, value):
-    # set request key
-    setattr(request, key, value)
-
-def get_session_key(request, key, default=None):
-    # get request key
     return getattr(request, key, default)
-"""
 
 
 def check_user_can_login(user):
